@@ -92,7 +92,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::group_by(Protein) %>%
       dplyr::mutate(dplyr::across(.cols = dplyr::everything(), .fns = \(x) median(x, na.rm = TRUE))) %>%
       dplyr::distinct() %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     f_data = pdata$f_data,
     e_meta = pdata$e_meta %>%
       dplyr::select(-Mass_Tag_ID) %>%
@@ -100,7 +100,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::mutate(peps_per_pro = dplyr::n()) %>%
       dplyr::mutate(n_peps_used = peps_per_pro) %>%
       dplyr::distinct(Protein, peps_per_pro, n_peps_used) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein",
     fdata_cname = "SampleID",
     emeta_cname = "Protein",
@@ -123,7 +123,7 @@ test_that('each rollup method correctly quantifies proteins', {
         .fns = pmartR:::combine_fn_mean
       )) %>%
       dplyr::distinct() %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     f_data = pdata$f_data,
     e_meta = pdata$e_meta %>%
       dplyr::select(-Mass_Tag_ID) %>%
@@ -133,7 +133,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::mutate(dplyr::across('Peptide_Sequence', \(x) paste(unique(x), collapse = ";"))) %>%
       dplyr::select(Protein, peps_per_pro, n_peps_used, Peptide_Sequence) %>%
       dplyr::distinct(.) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein",
     fdata_cname = "SampleID",
     emeta_cname = "Protein",
@@ -145,6 +145,40 @@ test_that('each rollup method correctly quantifies proteins', {
 
   # Set the protein quantitation method to rollup.
   attr(stan_mea, "pro_quant_info")$method <- "rollup"
+  
+  merged_abund <- merged
+  merged_abund[3:ncol(merged_abund)] <- exp(merged_abund[3:ncol(merged_abund)])
+  merged_abund <- merged_abund %>%
+    dplyr::select(-Mass_Tag_ID) %>%
+    dplyr::group_by(Protein) %>%
+    dplyr::mutate(dplyr::across(.cols = dplyr::everything(), 
+                                .fns = \(x) if(all(is.na(x))) sum(x) else sum(x, na.rm = TRUE))) %>%
+    dplyr::distinct() %>%
+    data.frame(check.names = FALSE)
+  merged_abund[-1] <- log(merged_abund[-1])
+  
+  # Standard for rollup - sum
+  stan_sum <- as.proData(
+    e_data = merged_abund,
+    f_data = pdata$f_data,
+    e_meta = pdata$e_meta %>%
+      dplyr::select(-Mass_Tag_ID) %>%
+      dplyr::group_by(Protein) %>%
+      dplyr::mutate(peps_per_pro = dplyr::n()) %>%
+      dplyr::mutate(n_peps_used = peps_per_pro) %>%
+      dplyr::distinct(Protein, peps_per_pro, n_peps_used) %>%
+      data.frame(check.names = FALSE),
+    edata_cname = "Protein",
+    fdata_cname = "SampleID",
+    emeta_cname = "Protein",
+    data_scale = "log"
+  )
+  
+  # Set the original data scale to abundance.
+  attr(stan_sum, "data_info")$data_scale_orig <- "abundance"
+  
+  # Set the protein quantitation method to rollup.
+  attr(stan_sum, "pro_quant_info")$method <- "rollup"
 
   # With filters and group_DF ---------------
 
@@ -158,7 +192,7 @@ test_that('each rollup method correctly quantifies proteins', {
         .fns = \(x) median(x, na.rm = TRUE)
       )) %>%
       dplyr::distinct() %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     f_data = pdata2$f_data,
     e_meta = pdata2$e_meta %>%
       dplyr::select(-Mass_Tag_ID) %>%
@@ -166,7 +200,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::mutate(peps_per_pro = dplyr::n()) %>%
       dplyr::mutate(n_peps_used = peps_per_pro) %>%
       dplyr::distinct(Protein, peps_per_pro, n_peps_used) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein",
     fdata_cname = "SampleID",
     emeta_cname = "Protein",
@@ -202,10 +236,19 @@ test_that('each rollup method correctly quantifies proteins', {
     isoformRes = NULL,
     emeta_cols = c("Peptide_Sequence")
   )
+  
+  # Quantitate using sum
+  pq_sum <- protein_quant(
+    pepData = pdata,
+    method = 'rollup',
+    combine_fn = 'sum',
+    isoformRes = NULL
+  )
 
   # Ensure the output from protein_quant matches the standards.
   expect_identical(pq_med, stan_med)
   expect_identical(pq_mea, stan_mea)
+  expect_identical(pq_sum, stan_sum)
 
   # With filters and group_DF ---------------
 
@@ -262,7 +305,7 @@ test_that('each rollup method correctly quantifies proteins', {
     )))
 
   # Produce an e_data object to create the rrollup standard.
-  edata_med <- data.frame(
+  edata_med <- data.frame(check.names = FALSE, 
     temp_med$Protein,
     data.table::rbindlist(temp_med$ratio)
   )
@@ -280,7 +323,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::mutate(peps_per_pro = dplyr::n()) %>%
       dplyr::mutate(n_peps_used = peps_per_pro) %>%
       dplyr::distinct(Protein, peps_per_pro, n_peps_used) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein",
     fdata_cname = "SampleID",
     emeta_cname = "Protein",
@@ -345,7 +388,7 @@ test_that('each rollup method correctly quantifies proteins', {
     )))
 
   # Produce an e_data object to create the qrollup standard.
-  edata_med <- data.frame(
+  edata_med <- data.frame(check.names = FALSE, 
     temp_med$Protein,
     data.table::rbindlist(temp_med$qtile)
   )
@@ -369,7 +412,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::mutate(peps_per_pro = dplyr::n()) %>%
       dplyr::mutate(n_peps_used = peps_per_pro) %>%
       dplyr::distinct(Protein, peps_per_pro, n_peps_used) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein",
     fdata_cname = "SampleID",
     emeta_cname = "Protein",
@@ -426,7 +469,7 @@ test_that('each rollup method correctly quantifies proteins', {
     scaled_pepes <- apply((cData - vector_mds) / vector_sds, 2, fn)
 
     protein[1, ] <- scaled_pepes
-    protein <- data.frame(protein)
+    protein <- data.frame(check.names = FALSE, protein)
     names(protein) <- names(cData)
 
     return(protein)
@@ -468,7 +511,7 @@ test_that('each rollup method correctly quantifies proteins', {
     )))
 
   # Produce an e_data object to create the qrollup standard.
-  edata_med <- data.frame(
+  edata_med <- data.frame(check.names = FALSE, 
     temp_med$Protein,
     data.table::rbindlist(temp_med$zombie)
   )
@@ -486,7 +529,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::mutate(peps_per_pro = dplyr::n()) %>%
       dplyr::mutate(n_peps_used = peps_per_pro) %>%
       dplyr::distinct(Protein, peps_per_pro, n_peps_used) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein",
     fdata_cname = "SampleID",
     emeta_cname = "Protein",
@@ -552,7 +595,7 @@ test_that('each rollup method correctly quantifies proteins', {
       dplyr::group_by(Protein_Isoform) %>%
       dplyr::mutate(dplyr::across(.cols = dplyr::everything(), .fns = \(x) median(x, na.rm = TRUE))) %>%
       dplyr::distinct() %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     f_data = pdata3$f_data,
     e_meta = attr(bayes, "isoformRes_subset") %>%
       dplyr::select(-Mass_Tag_ID) %>%
@@ -565,7 +608,7 @@ test_that('each rollup method correctly quantifies proteins', {
         Protein, Protein_Isoform, peps_per_pro,
         n_peps_used, Peptide_Sequence
       ) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein_Isoform",
     fdata_cname = "SampleID",
     emeta_cname = "Protein_Isoform",
@@ -606,7 +649,7 @@ test_that('each rollup method correctly quantifies proteins', {
     ))) %>%
     dplyr::select(Protein_Isoform, qtile) %>%
     tidyr::unnest(cols = c(Protein_Isoform, qtile)) %>%
-    data.frame()
+    data.frame(check.names = FALSE)
   rownames(edata_med) <- NULL
 
   # Match the protein counts with proteins in e_meta.
@@ -631,7 +674,7 @@ test_that('each rollup method correctly quantifies proteins', {
       ) %>% 
       dplyr::relocate(n_peps_used, .after = peps_per_pro) %>%
       dplyr::distinct(Protein, Protein_Isoform, peps_per_pro, n_peps_used) %>%
-      data.frame(),
+      data.frame(check.names = FALSE),
     edata_cname = "Protein_Isoform",
     fdata_cname = "SampleID",
     emeta_cname = "Protein_Isoform",
